@@ -1,6 +1,5 @@
 package Tree::RB::XS;
-$Tree::RB::XS::VERSION = '0.00_03'; # TRIAL
-$Tree::RB::XS::VERSION = '0.0003';
+$Tree::RB::XS::VERSION = '0.01';
 # VERSION
 # ABSTRACT: Similar API to Tree::RB implemented in C
 
@@ -28,7 +27,7 @@ sub new {
 	my $self= bless \%options, $class;
 	$self->_init_tree(delete $self->{key_type}, delete $self->{compare_fn});
 	$self->allow_duplicates(1) if delete $self->{allow_duplicates};
-	$self->compat_list_context(1) if delete $self->{compat_list_context};
+	$self->compat_list_get(1) if delete $self->{compat_list_get};
 	$self;
 }
 
@@ -53,6 +52,35 @@ sub rev_iter {
 sub Tree::RB::XS::Iter::next { shift->() }
 
 
+*Tree::RB::XS::Node::min=         *Tree::RB::XS::Node::left_leaf;
+*Tree::RB::XS::Node::max=         *Tree::RB::XS::Node::right_leaf;
+*Tree::RB::XS::Node::successor=   *Tree::RB::XS::Node::next;
+*Tree::RB::XS::Node::predecessor= *Tree::RB::XS::Node::prev;
+
+
+sub Tree::RB::XS::Node::strip {
+	my ($self, $cb)= @_;
+	my ($at, $next, $last)= (undef, $self->left_leaf || $self, $self->right_leaf || $self);
+	do {
+		$at= $next;
+		$next= $next->next;
+		if ($at != $self) {
+			$at->prune;
+			$cb->($at) if $cb;
+		}
+	} while ($at != $last);
+}
+
+sub Tree::RB::XS::Node::as_lol {
+	my $self= $_[1] || $_[0];
+	[
+		$self->left? $self->left->as_lol : '*',
+		$self->right? $self->right->as_lol : '*',
+		($self->color? 'R':'B').':'.($self->key||'')
+	]
+}
+
+
 *LUEQUAL= *GET_EQ;
 *LUGTEQ=  *GET_GE;
 *LUGTLT=  *GET_LE;
@@ -110,13 +138,36 @@ trusting it with production data.
 
 This module is a wrapper for a Red/Black Tree implemented in C.  It's primary features over
 other search trees on CPAN are optimized comparisons of keys (speed), C<< O(log N) >>
-node-by-index lookup (which allows the tree to double as a sort of array), and the option to
+node-by-index lookup (which allows the tree to act as an array), and the option to
 allow duplicate keys while preserving insertion order.
 
-The API is close but not identical to L<Tree::RB>, but can be configured to be fully compatible.
-In particular, the C<get> method in this module is not affected by array context unless you
-request C</compat_list_context>.  I also changed the documented names of a few methods, but
-include aliases for the Tree::RB name.
+The API is close but not identical to L<Tree::RB>.
+
+=over
+
+=item *
+
+The C<get> method in this module is not affected by array context, unless you
+request L</compat_list_get>.
+
+=item *
+
+C<resort> is not implemented (would be lots of effort, and unlikely to be needed)
+
+=item *
+
+tie-hash interface and hseek are not implemented.  (not hard, but does anyone need it?)
+
+=item *
+
+Tree structure is not mutable via the attributes of Node, nor can nodes be created
+independent from a tree.
+
+=item *
+
+Many functions have official names changed, but aliases are provided for compatibility.
+
+=back
 
 =head1 CONSTRUCTOR
 
@@ -145,7 +196,7 @@ Avoid using a coderef if possible.
 
 Whether to allow two nodes with the same key.  Defaults to false.
 
-=item L</compat_list_context>
+=item L</compat_list_get>
 
 Whether to enable full compatibility with L<Tree::RB>'s list-context behaviors.
 Defaults to false.
@@ -198,7 +249,7 @@ keys that already exist in the tree.  This does not change the behavior of L</pu
 only L</insert>.  If you set this to false, it does not remove duplicates that
 already existed.  The initial value is false.
 
-=head2 compat_list_context
+=head2 compat_list_get
 
 Boolean, read/write.  Controls whether C</get> returns multiple values in list context.
 I wanted to match the API of L<Tree::RB>, but I can't bring myself to make an innocent-named
@@ -297,6 +348,10 @@ You may use negative numbers to count down form max.
 
 Alias: C<nth>
 
+=head2 root
+
+Get the root node of the tree, or C<undef> if the tree is empty.
+
 =head2 iter
 
   my $iter= $tree->iter;
@@ -331,20 +386,33 @@ The data associated with the node.  Read/Write.
 
 =item prev
 
-The previous node in the sequence of keys.
+The previous node in the sequence of keys.  Alias C<predecessor> for C<Tree::RB::Node> compat.
 
 =item next
 
-The next node in the sequence of keys.
+The next node in the sequence of keys.  Alias C<successor> for C<Tree::RB::Node> compat.
+
+=item tree
+
+The tree this node belongs to.  This becomes C<undef> if the tree is freed or if the node
+is pruned from the tree.
 
 =item left
 
 The left sub-tree.
 
+=item left_leaf
+
+The left-most leaf of the sub-tree.  Alias C<min> for C<Tree::RB::Node> compat.
+
 =item right
 
 The right sub-tree.
 
+=item right_leaf
+
+The right-most child of the sub-tree.  Alias C<max> for C<Tree::RB::Node> compat.
+
 =item parent
 
 The parent node, if any.
@@ -368,6 +436,16 @@ And the following methods:
 Remove this single node from the tree.  The node will still have its key and value,
 but all attributes linking to other nodes will become C<undef>.
 
+=item strip
+
+Remove all children of this node, optionally calling a callback for each.
+For compat with L<Tree::RB::Node/strip>.
+
+=item as_lol
+
+Return sub-tree as list-of-lists. (array of arrays rather?)
+For compat with L<Tree::RB::Node/as_lol>.
+
 =back
 
 =head1 EXPORTS
@@ -505,7 +583,7 @@ Michael Conrad <mike@nrdvana.net>
 
 =head1 VERSION
 
-version 0.00_03
+version 0.01
 
 =head1 COPYRIGHT AND LICENSE
 
